(function (global, factory) {
    typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports, require('@angular/core'), require('rxjs'), require('@angular/forms')) :
    typeof define === 'function' && define.amd ? define('ngx-validate-helper', ['exports', '@angular/core', 'rxjs', '@angular/forms'], factory) :
    (global = global || self, factory(global['ngx-validate-helper'] = {}, global.ng.core, global.rxjs, global.ng.forms));
}(this, function (exports, core, rxjs, forms) { 'use strict';

    /*! *****************************************************************************
    Copyright (c) Microsoft Corporation. All rights reserved.
    Licensed under the Apache License, Version 2.0 (the "License"); you may not use
    this file except in compliance with the License. You may obtain a copy of the
    License at http://www.apache.org/licenses/LICENSE-2.0

    THIS CODE IS PROVIDED ON AN *AS IS* BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
    KIND, EITHER EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION ANY IMPLIED
    WARRANTIES OR CONDITIONS OF TITLE, FITNESS FOR A PARTICULAR PURPOSE,
    MERCHANTABLITY OR NON-INFRINGEMENT.

    See the Apache Version 2.0 License for specific language governing permissions
    and limitations under the License.
    ***************************************************************************** */

    function __decorate(decorators, target, key, desc) {
        var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
        if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
        else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
        return c > 3 && r && Object.defineProperty(target, key, r), r;
    }

    function __metadata(metadataKey, metadataValue) {
        if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(metadataKey, metadataValue);
    }

    var NgxValidatorDirective = /** @class */ (function () {
        function NgxValidatorDirective(template, viewContainer) {
            var _this = this;
            this.template = template;
            this.viewContainer = viewContainer;
            this.visibleSubject = new rxjs.BehaviorSubject(false);
            this.view = null;
            this.errorParameters = null;
            this.visibleSubject
                .subscribe(function (visibleStatus) {
                if (visibleStatus) {
                    _this.destroyView();
                    _this.view = _this.viewContainer.createEmbeddedView(_this.template, {
                        params: _this.errorParameters
                    });
                }
                else {
                    _this.destroyView();
                }
            });
        }
        /**
         * Sets error parameters for the current validator and gives a command to show an error
         * @param error - The parameters given by the validator of reactive forms. Example: Validator.minLength
         *                with parameter 8 will return: "{ requiredLength: 8, actualLength: 2 }"
         */
        NgxValidatorDirective.prototype.showError = function (error) {
            this.errorParameters = error;
            this.visibleSubject.next(true);
        };
        /**
         * Clear error parameters for the current validator and gives a command to hide an error
         */
        NgxValidatorDirective.prototype.hideErrors = function () {
            this.errorParameters = null;
            this.visibleSubject.next(false);
        };
        NgxValidatorDirective.prototype.destroyView = function () {
            if (this.view) {
                this.view.destroy();
            }
        };
        __decorate([
            core.Input('ngxValidator'),
            __metadata("design:type", String)
        ], NgxValidatorDirective.prototype, "validator", void 0);
        NgxValidatorDirective = __decorate([
            core.Directive({
                selector: '[ngxValidator]',
            }),
            __metadata("design:paramtypes", [core.TemplateRef,
                core.ViewContainerRef])
        ], NgxValidatorDirective);
        return NgxValidatorDirective;
    }());

    var ValidatableDirective = /** @class */ (function () {
        function ValidatableDirective() {
        }
        ValidatableDirective.prototype.ngAfterViewInit = function () {
            var _this = this;
            this.controls.forEach(function (control) {
                control.valueChanges.subscribe(function (data) {
                    _this.toggleAllValidatorItems(control);
                });
            });
        };
        ValidatableDirective.prototype.toggleAllValidatorItems = function (control) {
            var _this = this;
            this.validatorItems.forEach(function (validatorItem) {
                if (validatorItem.validator) {
                    _this.ToggleValidateItem(validatorItem, control);
                }
            });
        };
        ValidatableDirective.prototype.ngOnInit = function () {
        };
        ValidatableDirective.prototype.ToggleValidateItem = function (validatorItem, control) {
            if (control && control.dirty) {
                var error = control.getError(validatorItem.validator.toLowerCase());
                if (error) {
                    validatorItem.showError(error);
                }
                else {
                    validatorItem.hideErrors();
                }
            }
        };
        __decorate([
            core.ContentChildren(forms.NgControl),
            __metadata("design:type", core.QueryList)
        ], ValidatableDirective.prototype, "controls", void 0);
        __decorate([
            core.ContentChildren(NgxValidatorDirective),
            __metadata("design:type", core.QueryList)
        ], ValidatableDirective.prototype, "validatorItems", void 0);
        ValidatableDirective = __decorate([
            core.Directive({
                selector: '[ngxValidatable]',
            }),
            __metadata("design:paramtypes", [])
        ], ValidatableDirective);
        return ValidatableDirective;
    }());

    var NgxValidateHelperModule = /** @class */ (function () {
        function NgxValidateHelperModule() {
        }
        NgxValidateHelperModule = __decorate([
            core.NgModule({
                declarations: [ValidatableDirective, NgxValidatorDirective],
                imports: [],
                exports: [ValidatableDirective, NgxValidatorDirective],
            })
        ], NgxValidateHelperModule);
        return NgxValidateHelperModule;
    }());

    exports.NgxValidateHelperModule = NgxValidateHelperModule;
    exports.ValidatableDirective = ValidatableDirective;
    exports.ɵa = NgxValidatorDirective;

    Object.defineProperty(exports, '__esModule', { value: true });

}));
//# sourceMappingURL=ngx-validate-helper.umd.js.map
