import { __decorate, __metadata } from 'tslib';
import { Input, Directive, TemplateRef, ViewContainerRef, ContentChildren, QueryList, NgModule } from '@angular/core';
import { BehaviorSubject } from 'rxjs';
import { NgControl } from '@angular/forms';

let NgxValidatorDirective = class NgxValidatorDirective {
    constructor(template, viewContainer) {
        this.template = template;
        this.viewContainer = viewContainer;
        this.visibleSubject = new BehaviorSubject(false);
        this.view = null;
        this.errorParameters = null;
        this.visibleSubject
            .subscribe(visibleStatus => {
            if (visibleStatus) {
                this.destroyView();
                this.view = this.viewContainer.createEmbeddedView(this.template, {
                    params: this.errorParameters
                });
            }
            else {
                this.destroyView();
            }
        });
    }
    /**
     * Sets error parameters for the current validator and gives a command to show an error
     * @param error - The parameters given by the validator of reactive forms. Example: Validator.minLength
     *                with parameter 8 will return: "{ requiredLength: 8, actualLength: 2 }"
     */
    showError(error) {
        this.errorParameters = error;
        this.visibleSubject.next(true);
    }
    /**
     * Clear error parameters for the current validator and gives a command to hide an error
     */
    hideErrors() {
        this.errorParameters = null;
        this.visibleSubject.next(false);
    }
    destroyView() {
        if (this.view) {
            this.view.destroy();
        }
    }
};
__decorate([
    Input('ngxValidator'),
    __metadata("design:type", String)
], NgxValidatorDirective.prototype, "validator", void 0);
NgxValidatorDirective = __decorate([
    Directive({
        selector: '[ngxValidator]',
    }),
    __metadata("design:paramtypes", [TemplateRef,
        ViewContainerRef])
], NgxValidatorDirective);

let ValidatableDirective = class ValidatableDirective {
    constructor() {
    }
    ngAfterViewInit() {
        this.controls.forEach((control) => {
            control.valueChanges.subscribe((data) => {
                this.toggleAllValidatorItems(control);
            });
        });
    }
    toggleAllValidatorItems(control) {
        this.validatorItems.forEach((validatorItem) => {
            if (validatorItem.validator) {
                this.ToggleValidateItem(validatorItem, control);
            }
        });
    }
    ngOnInit() {
    }
    ToggleValidateItem(validatorItem, control) {
        if (control && control.dirty) {
            const error = control.getError(validatorItem.validator.toLowerCase());
            if (error) {
                validatorItem.showError(error);
            }
            else {
                validatorItem.hideErrors();
            }
        }
    }
};
__decorate([
    ContentChildren(NgControl),
    __metadata("design:type", QueryList)
], ValidatableDirective.prototype, "controls", void 0);
__decorate([
    ContentChildren(NgxValidatorDirective),
    __metadata("design:type", QueryList)
], ValidatableDirective.prototype, "validatorItems", void 0);
ValidatableDirective = __decorate([
    Directive({
        selector: '[ngxValidatable]',
    }),
    __metadata("design:paramtypes", [])
], ValidatableDirective);

let NgxValidateHelperModule = class NgxValidateHelperModule {
};
NgxValidateHelperModule = __decorate([
    NgModule({
        declarations: [ValidatableDirective, NgxValidatorDirective],
        imports: [],
        exports: [ValidatableDirective, NgxValidatorDirective],
    })
], NgxValidateHelperModule);

/*
 * Public API Surface of ngx-validate-helper
 */

/**
 * Generated bundle index. Do not edit.
 */

export { NgxValidateHelperModule, ValidatableDirective, NgxValidatorDirective as ɵa };
//# sourceMappingURL=ngx-validate-helper.js.map
